@@ -34,7 +34,9 @@ extern "C"
   typedef unsigned int uint32;
   typedef unsigned char uint8;
 
-#define NTLM_VERSION "1.5"
+#define NTLM_VERSION "1.8"
+
+#define NTLM_MSG_BUFSIZE 1024
 
 /*
  * These structures are byte-order dependant, and should not
@@ -55,7 +57,7 @@ extern "C"
     uint32 flags;
     tSmbStrHeader user;
     tSmbStrHeader domain;
-    uint8 buffer[1024];
+    uint8 buffer[NTLM_MSG_BUFSIZE];
     uint32 bufIndex;
   } tSmbNtlmAuthRequest;
 
@@ -68,7 +70,7 @@ extern "C"
     uint8 challengeData[8];
     uint8 reserved[8];
     tSmbStrHeader emptyString;
-    uint8 buffer[1024];
+    uint8 buffer[NTLM_MSG_BUFSIZE];
     uint32 bufIndex;
   } tSmbNtlmAuthChallenge;
 
@@ -84,7 +86,7 @@ extern "C"
     tSmbStrHeader uWks;
     tSmbStrHeader sessionKey;
     uint32 flags;
-    uint8 buffer[1024];
+    uint8 buffer[NTLM_MSG_BUFSIZE];
     uint32 bufIndex;
   } tSmbNtlmAuthResponse;
 
